# -*- coding: utf-8 -*-
import sys
import numpy as np
import matplotlib.pyplot as plt

INPUT_SIZES = [32,64,1024, 10000, 100000, 1000000]
ALGORITHMS = ["insertion", "merge", "tim"]
ALGORITHMS_TITLES = {"insertion": "Insertion Sort", "merge": "Merge Sort", "tim": "Tim Sort"}
MARKERS = {"insertion": "o", "merge": "s", "tim": "^"}

try:
    ordenacao = sys.argv[1]
except:
    ordenacao = ""

fig, axs = plt.subplots(2)

for algorithm in ALGORITHMS:

    tempos = []
    comparacoes = []

    for size in INPUT_SIZES:

        filename = algorithm+" n"+str(size)+ordenacao
        with open("outputs/"+filename) as file:
            dados = list(zip(*(line.strip().split('\t') for line in file)))
        tempos.append(np.mean(map(lambda x: float(x[:-1]), dados[0])))
        comparacoes.append(np.mean(map(lambda x: float(x[:-1]), dados[1])))
        print filename


    print "tempos "+str(tempos)
    print "comparacoes "+str(comparacoes)

    axs[0].plot(INPUT_SIZES, tempos, label=ALGORITHMS_TITLES[algorithm], marker=MARKERS[algorithm])
    axs[1].plot(INPUT_SIZES, comparacoes, label=ALGORITHMS_TITLES[algorithm], marker=MARKERS[algorithm])

axs[0].set_xlabel('Tamanho N da entrada'.decode('utf-8'))
axs[0].set_ylabel('Tempo(s)'.decode('utf-8'))
axs[0].set_xscale('log')
axs[0].set_yscale('log')
axs[0].legend()

axs[1].set_xlabel('Tamanho N da entrada'.decode('utf-8'))
axs[1].set_ylabel('Operações'.decode('utf-8'))
axs[1].set_xscale('log')
axs[1].set_yscale('log')
axs[1].legend()

plt.show()

